---
name: Feature Request
about: Request a new feature. Add a clear and concise description of what the feature addresses or solves and what you want to happen. The Arbor team will follow-up and help you get to an implementation.
title: ''
labels:
- 'Feature Request'
- 'help wanted'
- 'enhancement'
- 'neuroscience'
assignees: ''

---
<!-- Please add/remove relevant labels to categorize your feature. -->

**Describe the feature you need**
<!-- Example: I want Arbor to support file format X -->

**Explain what it is supposed to enable**
<!-- Example: Model database Y can export in format X, which means I could use their models in Arbor. -->

**Additional context**
<!-- Example: I'm writing a paper on the olfactory bulb and database Y has a model ready to go! -->
